==> tpcclib-0.7.9-src.tar.gz: v2/libtpctacmod/test_tpctacmod.h <==
#ifndef _TEST_TPCTACMOD_H_
#define _TEST_TPCTACMOD_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
/*****************************************************************************/
#include "tpctacmod.h"
/*****************************************************************************/

/*****************************************************************************/
/* litac */
extern int test_tacInterpolate(TPCSTATUS *status);
extern int test_tacInterpolateInto(TPCSTATUS *status);
extern int test_tacInterpolateToEqualLengthFrames(TPCSTATUS *status);
extern int test_tacFramesToSteps(TPCSTATUS *status);
extern int test_tacDelay(TPCSTATUS *status);
extern int test_tacAUC(TPCSTATUS *status);
extern int test_tacVb(TPCSTATUS *status);
extern int create_tac(TAC *tac);
extern int create_inp1(TAC *tac);
extern int create_inp2(TAC *tac);
extern int create_inp3(TAC *tac);
extern int create_tis1(TAC *tac);
/*****************************************************************************/

/*****************************************************************************/
#if(0)
/* litacrange */
extern int test_tacInterpolateCheckStart(TPCSTATUS *status);
extern int test_tacInterpolateCheckEnd(TPCSTATUS *status);
#endif
/*****************************************************************************/

/*****************************************************************************/
/* tacmodelinput */
extern int test_tacFittime(TPCSTATUS *status);
extern int test_tacReadModelingData(TPCSTATUS *status);
extern int test_tacReadReference(TPCSTATUS *status);
extern int test_tacReadModelingInput(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* tacfitplot */
extern int test_tacPlotFitSVG(TPCSTATUS *status);
extern int test_tacPlotLineSVG(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* partac */
extern int test_tacAllocateWithPAR(TPCSTATUS *status);
extern int test_parAllocateWithTAC(TPCSTATUS *status);
extern int test_tacToPAR(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCTACMOD */

==> tpcclib-0.8.1-src.tar.gz: v2/libtpctacmod/test_tpctacmod.h <==
#ifndef _TEST_TPCTACMOD_H_
#define _TEST_TPCTACMOD_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
/*****************************************************************************/
#include "tpctacmod.h"
/*****************************************************************************/

/*****************************************************************************/
/* litac */
extern int test_tacIntegrate(TPCSTATUS *status);
extern int test_tacInterpolate(TPCSTATUS *status);
extern int test_tacInterpolateInto(TPCSTATUS *status);
extern int test_tacInterpolateToEqualLengthFrames(TPCSTATUS *status);
extern int test_tacDelay(TPCSTATUS *status);
extern int test_tacAUC(TPCSTATUS *status);
extern int test_tacVb(TPCSTATUS *status);
extern int create_tac(TAC *tac);
extern int create_inp1(TAC *tac);
extern int create_inp2(TAC *tac);
extern int create_inp3(TAC *tac);
extern int create_tis1(TAC *tac);
/*****************************************************************************/

/*****************************************************************************/
/* lisim */
extern int test_tacInput2sim(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#if(0)
/* litacrange */
extern int test_tacInterpolateCheckStart(TPCSTATUS *status);
extern int test_tacInterpolateCheckEnd(TPCSTATUS *status);
#endif
/*****************************************************************************/

/*****************************************************************************/
/* tacmodelinput */
extern int test_tacFittime(TPCSTATUS *status);
extern int test_tacReadModelingData(TPCSTATUS *status);
extern int test_tacReadReference(TPCSTATUS *status);
extern int test_tacReadModelingInput(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* tacfitplot */
extern int test_tacPlotFitSVG(TPCSTATUS *status);
extern int test_tacPlotLineSVG(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* histplot */
extern int test_tacPlotHistogramSVG(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* partac */
extern int test_tacAllocateWithPAR(TPCSTATUS *status);
extern int test_parAllocateWithTAC(TPCSTATUS *status);
extern int test_tacToPAR(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCTACMOD */
